@@ -17,19 +17,25 @@
 import traceback as _traceback
 _p = _traceback.print_last
 
-from . import adalm2000  as _adalm2000
+from . import _gui_tools
+from . import _serial_tools
+
+from . import _adalm2000
 adalm2000_api = _adalm2000.adalm2000_api
 adalm2000     = _adalm2000.adalm2000
 
-from . import sillyscope as _sillyscope
+from . import _sillyscope
 sillyscope_api = _sillyscope.sillyscope_api
 sillyscope     = _sillyscope.sillyscope
 
-from . import keithley_dmm as _keithley_dmm
+from . import _keithley_dmm
 keithley_dmm_api = _keithley_dmm.keithley_dmm_api
 keithley_dmm     = _keithley_dmm.keithley_dmm
 
-from . import auber_syl53x2p as _auber_syl53x2p
+from . import _auber_syl53x2p
 auber_syl53x2p_api = _auber_syl53x2p.auber_syl53x2p_api
 auber_syl53x2p     = _auber_syl53x2p.auber_syl53x2p
 
+from . import _soundcard
+soundcard = _soundcard.soundcard
+
